.. _utilipy-ipython-notebook:

*********************************************
IPython Notebook (`utilipy.ipython.notebook`)
*********************************************

.. currentmodule:: utilipy.ipython.notebook


Reference/API
=============

.. automodapi:: utilipy.ipython.notebook
